@@ -175,12 +175,11 @@ class PlumXMetrics(Retrieval):
 
     def __str__(self):
         """Print a summary string."""
+        s = f"Document with {self.id_type} {self.identifier} received:\n- "
         cats = [f"{c.total:,} citation(s) in category '{c.name}'"
                 for c in self.category_totals]
-        date = self.get_cache_file_mdate().split()[0]
-        cats[0] += f" as of {date}"
-        s = f"Document with {self.id_type} {self.identifier} has "
-        s += ", ".join(cats)
+        s += "\n- ".join(cats)
+        s += f"\nas of {self.get_cache_file_mdate().split()[0]}"
         return s
 
 
