@@ -95,15 +95,16 @@ class SerialTitle(Retrieval):
 
     @property
     def sjrlist(self):
-        """The most recent SCImago Journal Rank (SJR) indicator as
-        (year, indicator)-tuple.  See
+        """The SCImago Journal Rank (SJR) indicator as list of
+        (year, indicator)-tuples.  See
         https://www.scimagojr.com/journalrank.php.
         """
         return _parse_list(self._entry, "SJR")
 
     @property
     def sniplist(self):
-        """Source-Normalized Impact per Paper (SNIP) of the source.  See
+        """The Source-Normalized Impact per Paper (SNIP) as list of
+        (year, indicator)-tuples.  See
         https://blog.scopus.com/posts/journal-metrics-in-scopus-source-normalized-impact-per-paper-snip.
         """
         return _parse_list(self._entry, "SNIP")
@@ -129,7 +130,7 @@ class SerialTitle(Retrieval):
         """The title of the source."""
         return self._entry['dc:title']
 
-    def __init__(self, issn, refresh=False, view="ENHANCED"):
+    def __init__(self, issn, refresh=False, view="ENHANCED", years=None):
         """Interaction with the Serial Title API.
 
         Parameters
@@ -147,6 +148,13 @@ class SerialTitle(Retrieval):
             BASIC, STANDARD, ENHANCED.  For details see
             https://dev.elsevier.com/guides/SerialTitleViews.htm.
 
+        years : str (optional, default=None)
+            A string specifying a year or range of years (combining two
+            years with a hyphen) for which yearly metric data (SJR, SNIP,
+            yearly-data) should be looked up for.  If None, only the
+            most recent metric data values are provided.
+            Note: If not None, refresh will always be True.
+
         Examples
         --------
         See https://pybliometrics.readthedocs.io/en/stable/examples/SerialTitle.html.
@@ -163,7 +171,11 @@ class SerialTitle(Retrieval):
                              ', '.join(allowed_views))
         # Load json
         self._id = str(issn)
-        Retrieval.__init__(self, identifier=self._id, view=view,
+        self._years = years
+        # Force refresh when years is specified
+        if years:
+            refresh = True
+        Retrieval.__init__(self, identifier=self._id, view=view, date=years,
                            api='SerialTitle', refresh=refresh)
         self._json = self._json['serial-metadata-response']
         self._entry = self._json['entry'][0]
@@ -180,20 +192,24 @@ class SerialTitle(Retrieval):
             f"'{self.publisher}', is active in {areas}\n"
         metrics = []
         if self.sjrlist:
-            metrics.append(f"SJR ({self.sjrlist[0]}): ({self.sjrlist[1]})")
+            metrics.append(f"SJR:  year value")
+            for rec in self.sjrlist:
+                metrics.append(f"      {rec[0]} {rec[1]}")
         if self.sniplist:
-            metrics.append(f"SNIP ({self.sniplist[0]}): ({self.sniplist[1]})")
+            metrics.append(f"SNIP: year value")
+            for rec in self.sniplist:
+                metrics.append(f"      {rec[0]} {rec[1]}")
         if metrics:
-            s += f"Metrics as of {date}:\n    " + ", ".join(metrics) + "\n"
+            s += f"Metrics as of {date}:\n    " + "\n    ".join(metrics) + "\n"
         s += f"    ISSN: {self.issn or '-'}, E-ISSN: {self.eissn or '-'}, "\
              f"Scopus ID: {self.source_id}"
         return s
 
 
-def _parse_list(d, list):
+def _parse_list(d, metric):
     """Auxiliary function to parse SNIP and SJR lists."""
-    keyword = list + "List"
     try:
-        return (d[keyword][list][0]['@year'], d[keyword][list][0]['$'])
-    except KeyError:
+        values = [(r['@year'], r['$']) for r in d[metric + "List"][metric]]
+        return sorted(set(values))
+    except (KeyError, TypeError):
         return None
