@@ -17,12 +17,12 @@ def create_config():
         config.add_section('Authentication')
         prompt_key = "Please enter your API Key(s), obtained from "\
                      "http://dev.elsevier.com/myapikey.html.  Separate "\
-                     "multple keys using a comma:\n"
+                     "multiple keys using a comma:\n"
         key = input(prompt_key)
         config.set('Authentication', 'APIKey', key)
         prompt_token = "API Keys are sufficient for most users.  If you "\
                        "have to use Authtoken authentication, please enter "\
-                       "the token, otherwise press Enter: \n"
+                       "the token now, otherwise press Enter:\n"
         token = input(prompt_token)
         if token:
             config.set('Authentication', 'InstToken', token)
@@ -33,7 +33,8 @@ def create_config():
             pass
         with open(CONFIG_FILE, 'w') as f:
             config.write(f)
-        print(f"Configuration file successfully created at {CONFIG_FILE}")
+        print(f"Configuration file successfully created at {CONFIG_FILE}\n"
+              "For details see https://pybliometrics.rtfd.io/en/stable/configuration.html.")
     else:
         text = f"Configuration file already exists at {CONFIG_FILE}; process "\
                "to create the file aborted.  Please open the file and edit "\
